==> checkstyle-8.45.1-tests.jar: com/puppycrawl/tools/checkstyle/checks/javadoc/summaryjavadoc/InputSummaryJavadocInlineDefault.java <==
/*
SummaryJavadocCheckTest
violateExecutionOnNonTightHtml = (default)false
forbiddenSummaryFragments = (default)^$
period = (default).


*/

package com.puppycrawl.tools.checkstyle.checks.javadoc.summaryjavadoc;

/**
 * Config: default.
 */
class InputSummaryJavadocInlineDefault {

    /**
     * {@summary A simple correct Javadoc.}
     */
    void foo1() {} // ok

    /**
     * {@summary This code is wrong }
     */
    void foo5(){} // violation

    /**
     * {@summary This code {@see Javadoc} is wrong }
     */
    void foo6(){} // violation

    /**
     * {@sometag This code {@see Javadoc} is wrong }
     */
    void foo7(){} // violation

    /**
     * {@summary <p>This code is right.</p>}
     */
    void foo8(){} // ok

    /**
     * {@summary As of , replaced by {@link #setBounds(int,int,int,int)}}
     */
    void foo11() {} // violation

    /**
     * {@summary {@throws Exception if a problem occurs}}
     */
    void foo12() throws Exception {} // violation

    /** {@summary An especially short bit of Javadoc.} */
    void foo13() {} // ok

    /**
     * {@summary Some Javadoc.}
     */
    public static final byte NUL = 0; // ok

    /**
     * {@summary <a href="mailto:vlad@htmlbook.ru"/>}
     */
    class InnerInputCorrectJavaDocParagraphCheck { // violation

        /**
         * {@summary foooo@foooo}
         */
        public static final byte NUL = 0; // violation

        /**
         * {@summary Some java@doc.}
         */
        public static final byte NUL_2 = 0; // ok

        /**
         * {@summary This method
         * returns some javadoc. Some javadoc.}
         */
        boolean emulated() {return false;} // ok

        /**
         * {@summary @return the
         * customer ID some javadoc.}
         */
        int geId() {return 666;} // ok

        /**
         * {@summary from {@link #setBounds(int,int,int,int)}.}
         */
        void foo3() {} // ok

        /** {@summary  An especially short bit of Javadoc.} */
        void foo5() {} // ok

        /**
         * {@summary An especially short bit of Javadoc.}
         */
        void foo6() {} // ok
    }

    /**
     * {@summary A {@code InnerInputCorrectJavaDocParagraphCheck} is a simple code.}
     */
    InputSummaryJavadocInlineDefault.InnerInputCorrectJavaDocParagraphCheck anon =
            new InputSummaryJavadocInlineDefault.InnerInputCorrectJavaDocParagraphCheck() {

        /**
         * Some Javadoc.
         */
        public static final byte NUL = 0; // ok

        /**
         * Some Javadoc.
         */
        void emulated(String s) {} // ok

        /**
         * from {@link #setBounds(int,int,int,int)}.
         */
        void foo3() {} // ok

        /**
         * {@summary {}@throws Exception if a problem occurs}
         */
        void foo4() throws Exception {} // violation

        /**
         * mm{@inheritDoc}
         */
        void foo7() {} // violation

        /**
         * {@link #setBounds(int,int,int,int)}
         */
        void foo8() {} // violation

        /**
         * {@summary {@code see} .}
         */
        void foo10() {} // ok
    };

    /**
     * {@summary M m m m {@inheritDoc}}
     */
    void foo14() {} // violation

    /**{@summary @summary .} */
    int foo15() {return 0;} // ok

    /**
     * {@summary @author Akash Mondal.}
     */
    void foo16(){} // ok

    /**
     * {@summary {@input Javadoc}.}
     */
    void foo17(){} // ok

    /**
     * {@summary}
     */
    void foo22() {} // violation

    /** */
    String[] foo9() {return null;} // violation

    /**
     * {@summary Javadoc {@code code} correct.}
     */
    void foo23(){} // ok

    /**
     * {@summary first doesn't have period
     * Use of html tags:
     * <ul>
     * <li>Item one.</li>
     * <li>Period here.</li>
     * </ul>}
     */
    private void invalidInlineJavadocTwo() // ok
    {
    }

    /**
     * {@summary first sentence is normally the summary.
     * Use of html tags:
     * {@code SomeCodeHere.}
     * <ul>
     * <li>Item one.</li>
     * <li>No period here</li>
     * </ul>}
     */
    private void invalidInlineJavadocList() // violation
    {
    }
}

==> checkstyle-9.3-tests.jar: com/puppycrawl/tools/checkstyle/checks/javadoc/summaryjavadoc/InputSummaryJavadocInlineDefault.java <==
/*
SummaryJavadoc
violateExecutionOnNonTightHtml = (default)false
forbiddenSummaryFragments = (default)^$
period = (default).


*/

package com.puppycrawl.tools.checkstyle.checks.javadoc.summaryjavadoc;

/**
 * Config: default.
 */
class InputSummaryJavadocInlineDefault {

    /**
     * {@summary A simple correct Javadoc.}
     */
    void foo1() {} // ok
    // violation below
    /**
     * {@summary This code is wrong }
     */
    void foo5(){}
    // violation below
    /**
     * {@summary This code {@see Javadoc} is wrong }
     */
    void foo6(){}
    // violation below
    /**
     * {@sometag This code {@see Javadoc} is wrong }
     */
    void foo7(){}

    /**
     * {@summary <p>This code is right.</p>}
     */
    void foo8(){} // ok
    // violation below
    /**
     * {@summary As of , replaced by {@link #setBounds(int,int,int,int)}}
     */
    void foo11() {}
    // violation below
    /**
     * {@summary {@throws Exception if a problem occurs}}
     */
    void foo12() throws Exception {}

    /** {@summary An especially short bit of Javadoc.} */
    void foo13() {} // ok

    /**
     * {@summary Some Javadoc.}
     */
    public static final byte NUL = 0; // ok
    // violation below
    /**
     * {@summary <a href="mailto:vlad@htmlbook.ru"/>}
     */
    class InnerInputCorrectJavaDocParagraphCheck {
    // violation below
        /**
         * {@summary foooo@foooo}
         */
        public static final byte NUL = 0;

        /**
         * {@summary Some java@doc.}
         */
        public static final byte NUL_2 = 0; // ok

        /**
         * {@summary This method
         * returns some javadoc. Some javadoc.}
         */
        boolean emulated() {return false;} // ok

        /**
         * {@summary @return the
         * customer ID some javadoc.}
         */
        int geId() {return 666;} // ok

        /**
         * {@summary from {@link #setBounds(int,int,int,int)}.}
         */
        void foo3() {} // ok

        /** {@summary  An especially short bit of Javadoc.} */
        void foo5() {} // ok

        /**
         * {@summary An especially short bit of Javadoc.}
         */
        void foo6() {} // ok
    }

    /**
     * {@summary A {@code InnerInputCorrectJavaDocParagraphCheck} is a simple code.}
     */
    InputSummaryJavadocInlineDefault.InnerInputCorrectJavaDocParagraphCheck anon =
            new InputSummaryJavadocInlineDefault.InnerInputCorrectJavaDocParagraphCheck() {

        /**
         * Some Javadoc.
         */
        public static final byte NUL = 0; // ok

        /**
         * Some Javadoc.
         */
        void emulated(String s) {} // ok

        /**
         * from {@link #setBounds(int,int,int,int)}.
         */
        void foo3() {} // ok
    // violation below
        /**
         * {@summary {}@throws Exception if a problem occurs}
         */
        void foo4() throws Exception {}
    // violation below
        /**
         * mm{@inheritDoc}
         */
        void foo7() {}
    // violation below
        /**
         * {@link #setBounds(int,int,int,int)}
         */
        void foo8() {}

        /**
         * {@summary {@code see} .}
         */
        void foo10() {} // ok
    };
    // violation below
    /**
     * {@summary M m m m {@inheritDoc}}
     */
    void foo14() {}

    /**{@summary @summary .} */
    int foo15() {return 0;} // ok

    /**
     * {@summary @author Akash Mondal.}
     */
    void foo16(){} // ok

    /**
     * {@summary {@input Javadoc}.}
     */
    void foo17(){} // ok
    // violation below
    /**
     * {@summary}
     */
    void foo22() {}

    /** */
    String[] foo9() {return null;} // violation above

    /**
     * {@summary Javadoc {@code code} correct.}
     */
    void foo23(){} // ok

    /**
     * {@summary first doesn't have period
     * Use of html tags:
     * <ul>
     * <li>Item one.</li>
     * <li>Period here.</li>
     * </ul>}
     */
    private void invalidInlineJavadocTwo() // ok
    {
    }
    // violation below
    /**
     * {@summary first sentence is normally the summary.
     * Use of html tags:
     * {@code SomeCodeHere.}
     * <ul>
     * <li>Item one.</li>
     * <li>No period here</li>
     * </ul>}
     */
    private void invalidInlineJavadocList()
    {
    }
}
